==> devextreme-angular-16.2.5.jar: META-INF/resources/webjars/devextreme-angular/16.2.5/ui/context-menu.d.ts <==
/*!
 * devextreme-angular
 * Version: 16.2.5
 * Build date: Tue Feb 28 2017
 *
 * Copyright (c) 2012 - 2017 Developer Express Inc. ALL RIGHTS RESERVED
 *
 * This software may be modified and distributed under the terms
 * of the MIT license. See the LICENSE file in the root of the project for details.
 *
 * https://github.com/DevExpress/devextreme-angular
 */
import { ElementRef, NgZone, OnDestroy, AfterViewInit, OnChanges, DoCheck, SimpleChanges, QueryList } from '@angular/core';
import DxContextMenu from 'devextreme/ui/context_menu';
import { DxComponent } from '../core/component';
import { DxTemplateHost } from '../core/template-host';
import { NestedOptionHost } from '../core/nested-option';
import { WatcherHelper } from '../core/watcher-helper';
import { IterableDifferHelper } from '../core/iterable-differ-helper';
import { DxiItemComponent } from './nested/item-dxi';
export declare class DxContextMenuComponent extends DxComponent implements OnDestroy, AfterViewInit, OnChanges, DoCheck {
    private _watcherHelper;
    private _idh;
    instance: DxContextMenu;
    elementAttr: any;
    height: any;
    rtlEnabled: any;
    width: any;
    accessKey: any;
    activeStateEnabled: any;
    disabled: any;
    focusStateEnabled: any;
    hint: any;
    hoverStateEnabled: any;
    tabIndex: any;
    visible: any;
    dataSource: any;
    itemTemplate: any;
    selectedItem: any;
    selectedItems: any;
    selectionByClick: any;
    selectionMode: any;
    items: any;
    disabledExpr: any;
    displayExpr: any;
    itemsExpr: any;
    selectedExpr: any;
    animation: any;
    cssClass: any;
    selectByClick: any;
    showSubmenuMode: any;
    closeOnOutsideClick: any;
    showEvent: any;
    submenuDirection: any;
    target: any;
    position: any;
    onDisposing: any;
    onInitialized: any;
    onOptionChanged: any;
    onContentReady: any;
    onItemClick: any;
    onItemContextMenu: any;
    onItemRendered: any;
    onSelectionChanged: any;
    onHidden: any;
    onHiding: any;
    onPositioning: any;
    onShowing: any;
    onShown: any;
    elementAttrChange: any;
    heightChange: any;
    rtlEnabledChange: any;
    widthChange: any;
    accessKeyChange: any;
    activeStateEnabledChange: any;
    disabledChange: any;
    focusStateEnabledChange: any;
    hintChange: any;
    hoverStateEnabledChange: any;
    tabIndexChange: any;
    visibleChange: any;
    dataSourceChange: any;
    itemTemplateChange: any;
    selectedItemChange: any;
    selectedItemsChange: any;
    selectionByClickChange: any;
    selectionModeChange: any;
    itemsChange: any;
    disabledExprChange: any;
    displayExprChange: any;
    itemsExprChange: any;
    selectedExprChange: any;
    animationChange: any;
    cssClassChange: any;
    selectByClickChange: any;
    showSubmenuModeChange: any;
    closeOnOutsideClickChange: any;
    showEventChange: any;
    submenuDirectionChange: any;
    targetChange: any;
    positionChange: any;
    itemsChildren: QueryList<DxiItemComponent>;
    constructor(elementRef: ElementRef, ngZone: NgZone, templateHost: DxTemplateHost, _watcherHelper: WatcherHelper, _idh: IterableDifferHelper, optionHost: NestedOptionHost);
    protected _createInstance(element: any, options: any): DxContextMenu;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngDoCheck(): void;
    ngAfterViewInit(): void;
}
export declare class DxContextMenuModule {
}

==> devextreme-angular-17.1.4.jar: META-INF/resources/webjars/devextreme-angular/17.1.4/ui/context-menu.d.ts <==
/*!
 * devextreme-angular
 * Version: 17.1.4
 * Build date: Thu Jun 29 2017
 *
 * Copyright (c) 2012 - 2017 Developer Express Inc. ALL RIGHTS RESERVED
 *
 * This software may be modified and distributed under the terms
 * of the MIT license. See the LICENSE file in the root of the project for details.
 *
 * https://github.com/DevExpress/devextreme-angular
 */
import { ElementRef, NgZone, OnDestroy, OnChanges, DoCheck, SimpleChanges, QueryList } from '@angular/core';
import DxContextMenu from 'devextreme/ui/context_menu';
import { DxComponent } from '../core/component';
import { DxTemplateHost } from '../core/template-host';
import { NestedOptionHost } from '../core/nested-option';
import { WatcherHelper } from '../core/watcher-helper';
import { IterableDifferHelper } from '../core/iterable-differ-helper';
import { DxiItemComponent } from './nested/item-dxi';
export declare class DxContextMenuComponent extends DxComponent implements OnDestroy, OnChanges, DoCheck {
    private _watcherHelper;
    private _idh;
    instance: DxContextMenu;
    elementAttr: any;
    height: any;
    rtlEnabled: any;
    width: any;
    accessKey: any;
    activeStateEnabled: any;
    disabled: any;
    focusStateEnabled: any;
    hint: any;
    hoverStateEnabled: any;
    tabIndex: any;
    visible: any;
    dataSource: any;
    itemTemplate: any;
    selectedItem: any;
    selectedItems: any;
    selectionByClick: any;
    selectionMode: any;
    items: any;
    disabledExpr: any;
    displayExpr: any;
    itemsExpr: any;
    selectedExpr: any;
    animation: any;
    cssClass: any;
    selectByClick: any;
    showSubmenuMode: any;
    closeOnOutsideClick: any;
    showEvent: any;
    submenuDirection: any;
    target: any;
    position: any;
    onDisposing: any;
    onInitialized: any;
    onOptionChanged: any;
    onContentReady: any;
    onItemClick: any;
    onItemContextMenu: any;
    onItemRendered: any;
    onSelectionChanged: any;
    onHidden: any;
    onHiding: any;
    onPositioning: any;
    onShowing: any;
    onShown: any;
    elementAttrChange: any;
    heightChange: any;
    rtlEnabledChange: any;
    widthChange: any;
    accessKeyChange: any;
    activeStateEnabledChange: any;
    disabledChange: any;
    focusStateEnabledChange: any;
    hintChange: any;
    hoverStateEnabledChange: any;
    tabIndexChange: any;
    visibleChange: any;
    dataSourceChange: any;
    itemTemplateChange: any;
    selectedItemChange: any;
    selectedItemsChange: any;
    selectionByClickChange: any;
    selectionModeChange: any;
    itemsChange: any;
    disabledExprChange: any;
    displayExprChange: any;
    itemsExprChange: any;
    selectedExprChange: any;
    animationChange: any;
    cssClassChange: any;
    selectByClickChange: any;
    showSubmenuModeChange: any;
    closeOnOutsideClickChange: any;
    showEventChange: any;
    submenuDirectionChange: any;
    targetChange: any;
    positionChange: any;
    itemsChildren: QueryList<DxiItemComponent>;
    constructor(elementRef: ElementRef, ngZone: NgZone, templateHost: DxTemplateHost, _watcherHelper: WatcherHelper, _idh: IterableDifferHelper, optionHost: NestedOptionHost);
    protected _createInstance(element: any, options: any): DxContextMenu;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngDoCheck(): void;
    _updateOption(name: string, value: any): void;
}
export declare class DxContextMenuModule {
}
